/*
   	Tairo v0.61
    Copyright (C) 2004 Jonas Gehring
        
    Tairo is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Tairo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tairo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// C Source File
// Created 30.10.04; 14:53:51

// Own headers
#include "tairo.h"						// Constants, proto-types etc.
// Biult-in headers
#include <estack.h>						// Routines for symbolic manipulation and expression handling
#include <graph.h>						// Common (non-windowed) graphic routines
#include <kbd.h>							// Keyboard handling routines
#include <compat.h>						// Various calc-dependent and AMS-dependent pseudo-constants
#include <intr.h>							// Routines for creating interrupt handlers
#include <stdio.h>						// ANSI-compatible file and TTY input/output routines
#include <system.h>						// System routines (for accessing system timers, queues, etc.)
#include <vat.h>							// Routines for accessing the variable allocation table
// Other headers
#include "extgraph.h"					// Include ExtGraph v2.00beta4 by TI-Chess Team


// Clears the screen. If we have no TI89, the unused space is filled with black
void ClearScr(void)
{
	ClearGrayScreen();
	
	// Fill the upper and lower space with balls
	if (CALCULATOR)
		FillWithBalls();
}


// Draws a box for messages
void DrawBox(void)
{
	GrayDrawRect(40+CALCX, 40+CALCY, 120+CALCX, 60+CALCY, COLOR_WHITE, RECT_FILLED);
	
	GrayDrawRect(39+CALCX, 39+CALCY, 121+CALCX, 61+CALCY, COLOR_DARKGRAY, RECT_EMPTY);
	GrayDrawRect(38+CALCX, 38+CALCY, 122+CALCX, 62+CALCY, COLOR_BLACK, RECT_EMPTY);
	
	// Draw a shadow
	GrayFastDrawLine(39+CALCX, 63+CALCY, 123+CALCX, 63+CALCY, COLOR_LIGHTGRAY);
	GrayFastDrawLine(123+CALCX, 39+CALCY, 123+CALCX, 62+CALCY, COLOR_LIGHTGRAY);
}


// Routine for saving
void Save(SAVE_LOAD *wininf)
{
	FILE *file = NULL;

	// Open file for writing
	if ((file = fopen("tairoinf", "wb")) == NULL) {
		return;
	} else {
		// Write data to the file
		if (fwrite(wininf, sizeof(SAVE_LOAD), 1, file) != 1) {
			return;
		}
	
		// Add the file ID tag
		fputc(0, file);
		fputs("high", file);
		fputc(0, file);
		fputc(OTH_TAG, file);
		
		// Close the file
		fclose(file);
	}
	
	// Achrchive the variable
	EM_moveSymToExtMem(NULL, FindSymInFolder(SYMSTR("tairoinf"), SYMSTR("main")));
}


// Routine for loading
BOOL Load(void)
{
	// SAVE_LOAD *wininf = NULL;
	FILE *file = NULL;

	// Unarchive the variable
	if (!EM_moveSymFromExtMem(NULL, FindSymInFolder(SYMSTR("tairoinf"), SYMSTR("main"))))
		return FALSE;
		
	// Open file for reading in binary mode
	if ((file = fopen("tairoinf", "rb")) == NULL) {
		return FALSE;
	} else {
		// Read data from file into th variable mode
		if (fread(&savload, sizeof(SAVE_LOAD), 1, file) != 1) {
			return FALSE;
		}

		// Close the file
		fclose(file);
			
		return TRUE;
	}
	
	return FALSE;
}